flup6
=====

This is a fork of Allan Saddi's flup package, it is intended to support both Python2
and Python3 from single code-base.

Installation
------------

.. code-block:: bash

    $ pip install flup6

Status
------

Package works on Python 3.3


License
-------

BSD
